slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPGetType

Gets the PEP type as a string from the PEP object.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPGetType(PEP pep,PEPType *type)

Not Collective

### Input Parameter

| pep | - the eigensolver context

### Output Parameter

| type | - name of PEP method

### See Also

PEPSetType()

### Level

intermediate

### Location

src/pep/interface/pepbasic.c

### Examples

src/pep/tutorials/ex16f90.F90.html
src/pep/tutorials/ex28.c.html
src/pep/tutorials/ex38.c.html
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages